@@ -45,11 +45,7 @@ namespace Do.Interface.AnimationBase
 			get { return bezel_drawing_area.Focus; }
 			set { bezel_drawing_area.Focus = value; }
 		}
-		
-		public new string Name { 
-			get { return RenderTheme.Name; }
-		}
-		
+
 		protected abstract IRenderTheme RenderTheme { get; }
 		
 		public AbstractAnimatedInterface () : base (Gtk.WindowType.Toplevel)
@@ -81,7 +77,10 @@ namespace Do.Interface.AnimationBase
 			
 			pw = new PositionWindow (this, bezel_glass_window);
 			
-			Realized += delegate { GdkWindow.SetBackPixmap (null, false); };
+			Realized += delegate {
+				GdkWindow.SetBackPixmap (null, false);
+				GdkWindow.OverrideRedirect = true;
+			};
 			
 			StyleSet += delegate {
 				if (IsRealized)
@@ -100,19 +99,24 @@ namespace Do.Interface.AnimationBase
 
 		protected override bool OnButtonPressEvent (EventButton evnt)
 		{
-			Gdk.Point global_point = new Gdk.Point ((int) evnt.XRoot, (int) evnt.YRoot);
-			Gdk.Point local_point = new Gdk.Point ((int) evnt.X, (int) evnt.Y);
+			Gdk.Point global_point = new Gdk.Point ((int)evnt.XRoot, (int)evnt.YRoot);
+			Gdk.Point local_point = new Gdk.Point ((int)evnt.X, (int)evnt.Y);
 			
 			switch (bezel_drawing_area.GetPointLocation (local_point)) {
-			case PointLocation.Close:
-			case PointLocation.Outside:
-				controller.ButtonPressOffWindow ();
-				break;
-			case PointLocation.Preferences:
-				Services.Windowing.ShowMainMenu (global_point.X, global_point.Y);
-				// Have to re-grab the pane from the menu.
-				Interface.Windowing.PresentWindow (this);
-				break;
+				case PointLocation.Close:
+				case PointLocation.Outside:
+					controller.ButtonPressOffWindow ();
+					break;
+				case PointLocation.Preferences:
+					// We need to let the window manager handle the Do window before popping up the
+					// preferences menu so that it can place the menu over the top.
+					GdkWindow.OverrideRedirect = false;
+					Services.Windowing.ShowMainMenu (global_point.X, global_point.Y);
+
+					// Have to re-grab the pane from the menu.
+					Interface.Windowing.PresentWindow (this);
+					GdkWindow.OverrideRedirect = true;
+					break;
 			}
 
 			return base.OnButtonPressEvent (evnt);
@@ -244,6 +248,12 @@ namespace Do.Interface.AnimationBase
 				return "preferences";
 			}
 		}
+
+		// This must be an explicit interface method to disambiguate between
+		// Widget.Name and IConfigurable.Name
+		string IConfigurable.Name {
+			get { return RenderTheme.Name; }
+		}
 		#endregion
 
 
