@@ -27,7 +27,7 @@ using Gtk;
 using Gdk;
 
 using Do.Universe;
-using Do.Platform;
+using Do.Platform.Linux;
 using Do.Interface;
 
 namespace Do.Interface.Widgets
@@ -453,7 +453,7 @@ namespace Do.Interface.Widgets
 			
 			using (cairo = Gdk.CairoHelper.Create (GdkWindow)) {
 				cairo.Rectangle (evnt.Area.X, evnt.Area.Y, evnt.Area.Width, evnt.Area.Height);
-				cairo.Color = new Cairo.Color (1.0, 1.0, 1.0, 0.0);
+				cairo.SetSourceRGBA (1.0, 1.0, 1.0, 0.0);
 				cairo.Operator = Cairo.Operator.Source;
 				cairo.Paint ();
 			}
