@@ -18,7 +18,11 @@
  */
 
 using System;
+#if USE_DBUS_SHARP
+using DBus;
+#else
 using NDesk.DBus;
+#endif
 
 namespace Do.Platform.Linux.DBus
 {
