@@ -19,13 +19,10 @@
 
 using System;
 
-using Gtk;
 using Gdk;
-using Mono.Unix;
 using LibNotify = Notifications;
 	
 using Do.Platform;
-using Do.Interface;
 
 namespace Do.Platform.Linux
 {	
