@@ -18,6 +18,8 @@
 //
 
 using System;
+using System.Collections.Generic;
+using System.Linq;
 
 using Do.Universe;
 using Do.Universe.Linux;
@@ -28,7 +30,6 @@ namespace Do.Platform.Linux
 	
 	public class UniverseFactoryService : IUniverseFactoryService
 	{
-		
 		public IFileItem NewFileItem (string path)
 		{
 			return new FileItem (path);
@@ -41,5 +42,10 @@ namespace Do.Platform.Linux
 			IApplicationItem maybe = ApplicationItem.MaybeCreateFromDesktopItem (path);
 			return maybe ?? new NullApplicationItem (path);
 		}
+		
+		public IApplicationItem MaybeApplicationItemFromCommand (string cmd)
+		{
+			return ApplicationItem.MaybeCreateFromCmd (cmd);
+		}
 	}
 }
