@@ -63,8 +63,6 @@ namespace Do.Universe.Linux {
 
 		static FileItem ()
 		{
-			Gnome.Vfs.Vfs.Initialize ();
-
 			// Initialize SpecialFolderIcons by expanding paths in
 			// SpecialFolderIconsXDG.
 			//
@@ -130,7 +128,11 @@ namespace Do.Universe.Linux {
 		}
 
 		public string MimeType {
-			get { return Gnome.Vfs.Global.GetMimeType (Path); }
+			get {
+				GLib.File file = GLib.FileFactory.NewFromCommandlineArg(Path);
+				var info = file.QueryInfo ("standard::content-type", GLib.FileQueryInfoFlags.None, null);
+				return info.ContentType;
+			}
 		}
 
 		public override string Icon {
@@ -142,8 +144,8 @@ namespace Do.Universe.Linux {
 				icon = MaybeGetSpecialFolderIconForPath (Path);
 				if (icon != null) return icon;
 
-				string large_thumb = Thumbnail.PathForUri (Uri, ThumbnailSize.Large);
-				string normal_thumb = Thumbnail.PathForUri (Uri, ThumbnailSize.Normal);
+				string large_thumb = Desktop.ThumbnailPathForUri (Uri, DesktopThumbnailSize.Large);
+				string normal_thumb = Desktop.ThumbnailPathForUri (Uri, DesktopThumbnailSize.Normal);
 
 				// Generating the thumbnail ourself is too slow for large files.
 				// Suggestion: generate thumbnails asynchronously. Banshee's
@@ -154,7 +156,7 @@ namespace Do.Universe.Linux {
 					icon = normal_thumb;	
 				} else {
 					try {
-						if (MimeType == "x-directory/normal") {
+						if (MimeType == "x-directory/normal" || MimeType == "inode/directory") {
 							icon = "folder";
 						} else if (MimeType.StartsWith ("image")) {
 							icon = "gnome-mime-image";
