@@ -11,18 +11,21 @@ namespace Do.Platform
 {
 	public class KeyBinding
 	{
+		public string PreferenceName { get; private set; }
 		public string Description { get; private set; }
 		public EventCallback Callback { get; private set; }
 		public string KeyString { get; set; }
 		public string DefaultKeyString { get; private set; }
 		public bool IsOSKey { get; private set; }
 
-		public KeyBinding (string description, string keyString, EventCallback eventFunc) : this (description, keyString, eventFunc, false)
+		public KeyBinding (string preferenceName, string description, string keyString, EventCallback eventFunc)
+			: this (preferenceName, description, keyString, eventFunc, false)
 		{
 		}
 		
-		public KeyBinding (string description, string keyString, EventCallback eventFunc, bool isoskey)
+		public KeyBinding (string preferenceName, string description, string keyString, EventCallback eventFunc, bool isoskey)
 		{
+			this.PreferenceName = preferenceName;
 			this.Description = description;
 			this.KeyString = keyString;
 			this.DefaultKeyString = keyString;
