@@ -55,9 +55,9 @@ namespace Do
 {
 	internal static class AssemblyInfo
 	{
-		public const string DisplayVersion = "0.95.1";
-		public const string VersionDetails = "bzr trunk r1403";
-		public const string LocaleDirectory = "/usr/local/share/locale";
+		public const string DisplayVersion = "0.95.3";
+		public const string VersionDetails = "bzr trunk r1408";
+		public const string LocaleDirectory = "/home/chris/.local/share/locale";
 	}
 }
 
